# Generated by Django 3.2.13 on 2022-06-23 02:07
from django.db import migrations

import wagtail.fields as wagtail_fields
import wagtail_color_panel.blocks


class Migration(migrations.Migration):
    dependencies = [
        ("testapp", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="pagewithstreamfield",
            name="body",
            field=wagtail_fields.StreamField(
                [("color", wagtail_color_panel.blocks.NativeColorBlock())],
                use_json_field=True,
            ),
        ),
    ]
